package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````0"$```````!``````````)`!`0``
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````'B>````````>)X`````````
M``$```````$````&````@/L```````"`^P$``````(#[`0``````"`4`````
M```P!0```````````0```````@````8```"0^P```````)#[`0``````D/L!
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````@)8```````"`E@```````("6````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````(#[````````@/L!``````"`^P$`
M`````(`$````````@`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`#FP0ALTZG8QNS>4W>A81)NUT
MV"\$````$`````$```!'3E4```````,````'`````````!$```!)````!```
M``@````A$!``!<`$A"@"$`6`AD"$@HD`!@D@!(B(@!!!N@`""$D```!*````
M30```%$```!2````6P```%P```!=`````````%\```!@````80```&(```!C
M````9@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_
MY`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/JA;&"93\.;:PE#
MUF>OS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)
M```````````````````````````````````````````#``L`^!H`````````
M```````````````#`!8````"`````````````````.0````2````````````
M`````````````,T!```2`````````````````````````)8````2````````
M`````````````````%T!```2`````````````````````````)P!```2````
M`````````````````````-P!```2`````````````````````````/H````2
M``````````````````````````$````@`````````````````````````!@"
M```2`````````````````````````!$"```2````````````````````````
M`*L#```2`````````````````````````"L!```2````````````````````
M`````.D"```1`````````````````````````!L!```2````````````````
M`````````*`"```2``````````````````````````T!```2````````````
M`````````````"$"```2`````````````````````````)<!```2````````
M`````````````````,4!```2`````````````````````````*0!```2````
M`````````````````````&T"```B`````````````````````````!`````@
M`````````````````````````/4!```2`````````````````````````'L!
M```2`````````````````````````"P````@````````````````````````
M`+4!```2`````````````````````````,4"```2````````````````````
M`````$8"```2`````````````````````````)D"```2````````````````
M`````````%\"```1`````````````````````````+\"```2````````````
M`````````````$8````2`````````````````````````&,````6````````
M`````````````````$T!```2`````````````````````````'8````2````
M`````````````````````.H!```2`````````````````````````-,````2
M`````````````````````````(<````2`````````````````````````)("
M```2`````````````````````````*X"```2````````````````````````
M`-<"```2`````````````````````````/`!```2````````````````````
M`````#<"```2`````````````````````````+<````2````````````````
M`````````(8!```2``````````````````````````("```2````````````
M`````````````#\!```2`````````````````````````'0!```2````````
M`````````````````.X````2`````````````````````````$4"```2````
M`````````````````````*<"```2`````````````````````````(H"```2
M`````````````````````````*X!```2`````````````````````````*(`
M```2`````````````````````````'P"```2````````````````````````
M`&@!```2`````````````````````````/P!```2````````````````````
M`````&8"```2`````````````````````````,8````1````````````````
M`````````.D````2`````````````````````````#0!```2````````````
M`````````````%0````2`````````````````````````-0!```2````````
M`````````````````$T"```2`````````````````````````,T"```1````
M`````````````````````+X!```2`````````````````````````.,!```2
M`````````````````````````"D"```2`````````````````````````,\"
M```1`````````````````````````(,"```2````````````````````````
M``8$```0`!<`L``"`````````````````+0#```2``T`P#\````````$`0``
M`````"L$```2``T`5#<````````T!@```````%H"```2``T``!\````````8
M`@```````"L#```2``T`4"H````````(`````````$D#```2``T`D#T`````
M```H`@```````-P#```0`!<`B``"`````````````````%$$```2``T`8"H`
M``````!<`@```````!$$```0`!<`B``"`````````````````#P#```2``T`
MP"P````````T`````````%\#```2``T`5#,```````"``````````,`#```1
M``\`X%0````````$`````````.H#```2``T`X%$````````,`0```````/4#
M```2``T`,"D````````P`````````/T#```0`!<`L``"````````````````
M`"8$```0`!<`L``"`````````````````#\$```2``T`$#8```````!$`0``
M`````&@$```2``T`U#,```````"L`````````,\#```0`!8````"````````
M`````````(,#```2``T`]"P```````"(`0```````#@$```0`!8`B``"````
M`````````````%X$```1`!8`@``"```````(`````````-4#```2``T`0"$`
M```````T`````````!T$```2``T`D%$```````!(`````````-$#```@`!8`
M```"`````````````````)D#```2``T`X#4````````H`````````&T#```2
M``T`8"D```````#L`````````(\#```2``T`\%(```````#0`0````````4$
M```0`!<`L``"`````````````````'`$```2``T`@"X```````#4!```````
M``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?
M<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K
M`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L
M86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?8VAK7V9A
M:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E
M;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I
M<@!R96%D`'-T<G-T<@!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`<F5A
M9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T
M870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I
M;F%L:7IE`'-T<F-H<@!M96US970`;W!E;F1I<@!G971U:60`86-C97-S`&UE
M;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?
M96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L
M:6)P97)L+G-O+C4N,S8`;&EB8RYS;RXV`&QD+6QI;G5X+6%A<F-H-C0N<V\N
M,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?
M7V)S<U]S=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N9%]?`%]?8G-S
M7V5N9%]?`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER
M`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R
M7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,3<`1TQ)0D-?,BXS
M-`!'3$E"0U\R+C,S``````````$``@`!``$``@`"``$``0`"``(``@`!``,`
M`0`"``$``@`"``(``@`"``$``@`!``$``@`"``0``@`"``(``0`!``$``0`"
M``$``0`"``(``@`"``(``0`"``(``0`"``$`!``"``(``@`!``(``0`"``(`
M`0`"``$``0`"``4``@`"``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$```````$`
M`0`5`P``$````"````"7D98&```#`'T$`````````0`#``L#```0````````
M`+21E@8```4`B`0``!````"SD98&```$`),$```0````EY&6!@```@!]!```
M`````(#[`0```````P0```````!0(@```````(C[`0```````P0`````````
M(@```````/C_`0```````P0`````````'P````````@``@```````P0`````
M```(``(``````"```@```````P0```````#`6````````"@``@```````P0`
M``````!050```````#@``@```````P0```````!`5@```````$```@``````
M`P0```````"@6````````$@``@```````P0```````"H6````````%```@``
M`````P0```````"P6````````%@``@```````P0```````"X6````````&@`
M`@```````P0```````"(6````````'```@```````P0```````"06```````
M`(```@```````P0```````#(6````````)C_`0```````00```D`````````
M`````*#_`0```````00```H``````````````*C_`0```````00```\`````
M`````````+#_`0```````00``!<``````````````+C_`0```````00``!@`
M`````````````,#_`0```````00``!L``````````````,C_`0```````00`
M`"```````````````-#_`0``````!@0``",``````````````-C_`0``````
M`00``"0``````````````.#_`0```````00``"4``````````````.C_`0``
M`````00``#T``````````````/#_`0```````00``$<``````````````+C]
M`0```````@0```,``````````````,#]`0```````@0```0`````````````
M`,C]`0```````@0```4``````````````-#]`0```````@0```8`````````
M`````-C]`0```````@0```<``````````````.#]`0```````@0```@`````
M`````````.C]`0```````@0```H``````````````/#]`0```````@0```L`
M`````````````/C]`0```````@0```P```````````````#^`0```````@0`
M``T```````````````C^`0```````@0```X``````````````!#^`0``````
M`@0``!```````````````!C^`0```````@0``!$``````````````"#^`0``
M`````@0``!(``````````````"C^`0```````@0``!,``````````````##^
M`0```````@0``!0``````````````#C^`0```````@0``!4`````````````
M`$#^`0```````@0``!8``````````````$C^`0```````@0``!<`````````
M`````%#^`0```````@0``!D``````````````%C^`0```````@0``!H`````
M`````````&#^`0```````@0``!P``````````````&C^`0```````@0``!T`
M`````````````'#^`0```````@0``!X``````````````'C^`0```````@0`
M`!\``````````````(#^`0```````@0``"$``````````````(C^`0``````
M`@0``"(``````````````)#^`0```````@0``"8``````````````)C^`0``
M`````@0``"<``````````````*#^`0```````@0``"@``````````````*C^
M`0```````@0``"D``````````````+#^`0```````@0``"H`````````````
M`+C^`0```````@0``"L``````````````,#^`0```````@0``"P`````````
M`````,C^`0```````@0``"T``````````````-#^`0```````@0``"X`````
M`````````-C^`0```````@0``"\``````````````.#^`0```````@0``#``
M`````````````.C^`0```````@0``#$``````````````/#^`0```````@0`
M`#(``````````````/C^`0```````@0``#,```````````````#_`0``````
M`@0``#0```````````````C_`0```````@0``#4``````````````!#_`0``
M`````@0``#8``````````````!C_`0```````@0``#<``````````````"#_
M`0```````@0``#@``````````````"C_`0```````@0``#D`````````````
M`##_`0```````@0``#H``````````````#C_`0```````@0``#L`````````
M`````$#_`0```````@0``#P``````````````$C_`0```````@0``#X`````
M`````````%#_`0```````@0``#\``````````````%C_`0```````@0``$``
M`````````````&#_`0```````@0``$$``````````````&C_`0```````@0`
M`$(``````````````'#_`0```````@0``$0``````````````'C_`0``````
M`@0``$4``````````````(#_`0```````@0``$8``````````````(C_`0``
M`````@0``$@``````````````!\@`]7]>[^I_0,`D9P!`)3]>\&HP`-?UO![
MOZGP``#0$=I&^1#"-I$@`A_6'R`#U1\@`]4?(`/5\```T!'>1OD0XC:1(`(?
MUO```-`1XD;Y$`(WD2`"'];P``#0$>9&^1`B-Y$@`A_6\```T!'J1OD00C>1
M(`(?UO```-`1[D;Y$&(WD2`"'];P``#0$?)&^1""-Y$@`A_6\```T!'V1OD0
MHC>1(`(?UO```-`1^D;Y$,(WD2`"'];P``#0$?Y&^1#B-Y$@`A_6\```T!$"
M1_D0`CB1(`(?UO```-`1!D?Y$"(XD2`"'];P``#0$0I'^1!".)$@`A_6\```
MT!$.1_D08CB1(`(?UO```-`1$D?Y$((XD2`"'];P``#0$19'^1"B.)$@`A_6
M\```T!$:1_D0PCB1(`(?UO```-`1'D?Y$.(XD2`"'];P``#0$2)'^1`".9$@
M`A_6\```T!$F1_D0(CF1(`(?UO```-`1*D?Y$$(YD2`"'];P``#0$2Y'^1!B
M.9$@`A_6\```T!$R1_D0@CF1(`(?UO```-`1-D?Y$*(YD2`"'];P``#0$3I'
M^1#".9$@`A_6\```T!$^1_D0XCF1(`(?UO```-`10D?Y$`(ZD2`"'];P``#0
M$49'^1`B.I$@`A_6\```T!%*1_D00CJ1(`(?UO```-`13D?Y$&(ZD2`"'];P
M``#0$5)'^1"".I$@`A_6\```T!%61_D0HCJ1(`(?UO```-`16D?Y$,(ZD2`"
M'];P``#0$5Y'^1#B.I$@`A_6\```T!%B1_D0`CN1(`(?UO```-`19D?Y$"([
MD2`"'];P``#0$6I'^1!".Y$@`A_6\```T!%N1_D08CN1(`(?UO```-`1<D?Y
M$(([D2`"'];P``#0$79'^1"B.Y$@`A_6\```T!%Z1_D0PCN1(`(?UO```-`1
M?D?Y$.([D2`"'];P``#0$8)'^1`"/)$@`A_6\```T!&&1_D0(CR1(`(?UO``
M`-`1BD?Y$$(\D2`"'];P``#0$8Y'^1!B/)$@`A_6\```T!&21_D0@CR1(`(?
MUO```-`1ED?Y$*(\D2`"'];P``#0$9I'^1#"/)$@`A_6\```T!&>1_D0XCR1
M(`(?UO```-`1HD?Y$`(]D2`"'];P``#0$:9'^1`B/9$@`A_6\```T!&J1_D0
M0CV1(`(?UO```-`1KD?Y$&(]D2`"'];P``#0$;)'^1""/9$@`A_6\```T!&V
M1_D0HCV1(`(?UO```-`1ND?Y$,(]D2`"'];P``#0$;Y'^1#B/9$@`A_6\```
MT!'"1_D0`CZ1(`(?UO```-`1QD?Y$"(^D2`"']8`````````````````````
M`````````````````````#\C`]7_@P'1XP``T&/41_G]>P.I_<,`D>*'`*GB
M(P"1X4,`D>`?`+G@<P"1\U,$J?5;!:ED`$#YY!<`^00`@-+,__^7X@``T$+,
M1_G@``#0`/!'^>$#`JI:#0"4X```T`#T1_D``$`Y@`D`-N```-``Z$?Y0=`[
MU?,``/`B:&#X]!]`N4$H4CF`$@`1E`X`$2$$`#)!*!(Y`'Q]DZ'__Y?C`P"J
MY@M`^>```/!B0@*1Y1]`N01`0/DA``"0QP!`^2'@(9$@``"0```BD6<$`*E#
M!`#Y9``!J;\$`'%-"0!4(0"`TA\@`]4@#``1Q'AA^"$$`)%DV"#XOP`!:VS_
M_U2E#``1=4("D7_8)?@!``"0X@,4*B$`(Y$$`(#2H`Y`^=#^_Y<@!0`T=4("
MD?:3`)&@#D#Y5___E_0#`"KA`Q:J````\`!`%Y&&``"40`0`M'-"`I%@#D#Y
MMO[_EQW__Y?@``"P`-1'^>(70/D!`$#Y0@`!ZP$`@-+A!`!4_7M#J>`#%"KS
M4T2I]5M%J?^#`9&_(P/5P`-?UO;^_Y?S``#08D("D4`,`/D@`P"T%?__E^``
M`+``Z$?Y0=`[U2)H8/A?W"@YKO__%Z`.0/G!_O^7UO__%Z`*0/E@``"TN0<`
ME-S__Q?A`Q:J````\`!@%9%<``"4H`H`^<#Z_[2Q!P"4U/__%X4`@%*___\7
M(`"`4L3^_Y<7__^7'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?
M(`/5'R`#U1\@`]4=`(#2'@"`TN4#`*KA`T#YXB,`D>8#`)'@``"P`/Q'^0,`
M@-($`(#22?__E]3^_Y?@``"P`-!'^4```+2$_O\7P`-?UA\@`]4?(`/5X```
MT``@`I'A``#0(2`"D3\``.O```!4X0``L"'<1_EA``"T\`,!J@`"'];``U_6
MX```T``@`I'A``#0(2`"D2$``,LB_'_300R!BR'\09/!``"TX@``L$+@1_EB
M``"T\`,"J@`"'];``U_6'R`#U?U[OJG]`P"1\PL`^?,``-!@(D(Y0`$`-^``
M`+``V$?Y@```M.```-``!$#YB?[_E]C__Y<@`(!28"(".?,+0/G]>\*HP`-?
MUA\@`]4?(`/5W/__%Q\@`]4?(`/5'R`#U3\C`]7]>[RI_0,`D?-3`:G`!@"T
M]V,#J?<#`*K@``"P`/A'^1@`0/E8!@"T]5L"J?8#`:H5`(!2X`)`.1_T`'$$
M&$!ZP0(`5!,#0/FS`0"TM7Y`D_0#&*KB`Q6JX0,7JN`#$ZIS_O^7@```-6!J
M=3@?]`!Q(`(`5)..0/CS_O^U]5M"J?=C0ZG@`Q.J\U-!J?U[Q*B_(P/5P`-?
MUO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^7__Q>``AC+M08`D7,"%8L`_$.3
MP`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HOR,#U<`#7]83`(#2Y___%_=C0ZD3
M`(#2Y/__%Q\@`]4_(P/5_\,"T>(``+!"U$?YX2,`D?U[":G]0P*1\U,`^?,#
M`*I#`$#YXT<`^0,`@-*,_O^78`(`->$;0+D"`)12(0P4$C\00'$D$$)ZX`$`
M5.$``+`AU$?YXT=`^2(`0/EC``+K`@"`TL$!`%3]>TFI\U-`^?_#`I&_(P/5
MP`-?U@``@%+S__\7X`,3JD$`@%(P_O^7'P``<>`7GQKM__\77/[_ES\C`]7_
M`P/1X0``L"'41_G]>PFI_4,"D2(`0/GB1P#Y`@"`TL```+3S4PJI\P,`J@$`
M0#FA`0`U\U-*J>```+``U$?YXD=`^0$`0/E"``'K`0"`TL$(`%3]>TFI_P,#
MD;\C`]7``U_6]5L+J5S^_Y?T`P"J0`8`M.`#%*KP_?^78`4`M`%,0#D53`"1
M/[@`<6$``%2A!D`Y`?__-`!,0#D?N`!Q(`4`5.`#$ZJ`_O^7]@,`JN`#%:I]
M_O^7P`(`"P`(`!$`?$"3-?[_E^4#%:KD`Q.J`P``\&.@$Y$"`("2]0,`JB$`
M@%)U_O^7X2,`D>`#%:KJ_?^7'P0`,:```%3@&T"Y``P4$A\00'&@`@!4X`,5
MJHK]_Y?@`Q6J3/[_E^`#%*K&_?^7X/K_M>`#%*K3_?^7X`,3JNG]_Y?S4TJI
M]5M+J;[__Q>@!D`Y'[@`<<'Z_U2@"D`Y`/G_--/__Q?@`Q6JI___E^S__Q?S
M4PJI]5L+J?[]_Y<?(`/5/R,#U?^#`=']>P&I_4,`D?-3`JGS`P"J]`,!JO5;
M`ZGW8P2IX```L`#41_DA`$`Y`@!`^>('`/D"`(#2/_0`<906E)K@`Q2J.O[_
ME_8#`*KA$P"1X`,3JB+__Y>`"`"T]0,`JC/^_Y??`@#K*0<`5/<'@+GX``"P
M&/M'^??R?=-@`D`Y'_0`<0080'H@#`!4Y`,3JA\@`]6#'$`X?_0`<6080'JA
M__]4A``3RX1\0),5`T#YP`H`D0``!(O9_?^7H&HW^*`"`+0!`T#YX`,3JB-H
M=_@!%$`X80``.3_T`'$D&$!ZP```5`(40#AB'``X7_0`<4080'J!__]4H0>`
M4@``@-)A%``X@FI@.&)H(#@`!`"1HO__->```+``U$?YX@=`^0$`0/E"``'K
M`0"`TJ$'`%3]>T&I\U-"J?5;0ZGW8T2I_X,!D;\C`]7``U_6`0"`TA\@`]6"
M:F$XHFHA."$$`)&B__\U[/__%_@``+`8^T?Y^6L%J1H#0/E``T#YP`0`M.`#
M&JH5`(!2'R`#U0&,0/CB`Q4JM08`$:'__[5`#``1`'Q]D^$``-`BD$"Y`@(`
M-2(`@%(BD`"YF?W_E_D#`*I``P"TMWY]D^$#&JKB`Q>JR_W_EQD#`/F@!@`1
M]0<`N3_;(/CY:T6II?__%^$#`*K@`QJJ)OW_EP`#`/GY`P"J0`$`M+=^?9/T
M__\7!`"`TJ?__Q<``H#2%0"`4N+__Q?Y:P6I<OW_E_EK1:FZ__\7/R,#U?U[
MO:D-`H+2_0,`D?-3`:GU6P*I_V,MR_\#`OGC``"P8]1'^?4C`)'S`P"J]`,!
MJF``0/G@!PCY``"`TN$#%:H```#PXO^!T@#`$Y'G_/^7'P``<<T``%0$!`!1
MX@,`*J#*9#@@`P`UQ`(`->```+``Z$?Y0]`[U>(#%*KA`Q.J8&A@^/'\_Y?@
M``"P`-1'^>('2/D!`$#Y0@`!ZP$`@-(A`P!4#0*"TO]C+8OS4T&I]5M"J?U[
MPZB_(P/5P`-?UN(#!"H?(`/55GQ`D^`#%:KB`Q:JX06`4FS]_Y>`_/^TX```
ML`#H1_E$T#O5XP,6JN(#%:KA`Q.J@&A@^"O]_Y?B__\7+?W_ES\C`]7]>[ZI
M(P``\/T#`)'S4P&I5-`[U?,``+!SZD?YX@``L$+L1_ECX!B1`0``\"$`%)&`
M:G/X6OW_EX!J<_@$``#P\U-!J83`(9']>\*HOR,#U>,#!*H"``"P`0``\$)`
M-I$A@!21!0"`4O'\_Q=?)`/5X```L`#H1_E$T#O5X@``L$+L1_DC``#P`0``
M\&/@&)&`:&#X(0`4D4']_Q<_(P/5_7N]J0T$A-+]`P"1\U,!J?43`/G_8RW+
M_P,"^>```+``U$?Y\R,`D10`@-(!`$#YX0\0^0$`@-*%_/^7Y`,`*@4``/`#
M``#PI>`4D6,`%9$B`(+2(0"`4N`#$ZI`_?^7``*"TO5C((OA`Q6JX`,3J@(`
M@M)R_/^7@`'X-_,#`*H`!``1`'Q`D^W\_Y?T`P"JP```M'-^0)/A`Q6JX@,3
MJGO\_Y>?:C,XX```L`#41_GB#U#Y`0!`^4(``>L!`(#2(0$`5`T$A-+_8RV+
MX`,4JO-30:GU$T#Y_7O#J+\C`]7``U_6ROS_EQ\@`]5?)`/5P___%Q\@`]4?
M(`/5/R,#U?U[NZD-$H+2_0,`D?-3`:GU6P*I_V,MR_\#`OGB``"P0M1'^?4#
M`*KS`P&JX1,`D4``0/G@1PCY``"`T@```/``8!61[OW_E_0#`*KA!8!2X`,5
MJM;\_Y>``@"TX0,5J@```/``H!61K?[_E^`#%:KA``"P(=1'^>-'2/DB`$#Y
M8P`"ZP(`@-+A#0!4#1*"TO]C+8OS4T&I]5M"J?U[Q:B_(P/5P`-?UN`#$ZJX
M_/^7%@``\,'B%9$9_/^7\P,`JN#\_[3W8PCY]R,"D?AG"/D8``#P&",6D?EK
M"/D9``#P.0,6D?IO"/D?(`/58`)`.>`&`#2T``"TX0,3JN`#%*J;_/^7``4`
M-.`#$ZK0_/^7`@0`T?H#`*IB`@*+?P("ZZ,``%0*```47_0?.'\"`NN```!4
M0`!`.1^\`'%@__]4X`,3JL+\_Y?Z`P"JX`,5JK_\_Y<``!J+``0`D1_\/_'(
M`@!4Y`,3JN8#%:KE`QFJXP,8J@(`@M(A`(!2X`,7JK?\_Y?A(P"1X`,7JBS\
M_Y>@```UX!M`N0`,%!(?($!QP`(`5,'B%9$``(#2W/O_E_,#`*K`^?^U]V-(
M^?AG2/GY:TCY^F](^:7__Q=4`P"T@`)`.1^X`'&@``!4$P``\#H`@-)S0A61
MV?__%X`&0#F@_?\T^O__%^`#%ZHA`(!2$_S_EP#]_S7A`Q>J````\`"@%9%"
M_O^7X`,7JES\_Y?W8TCY^&=(^?EK2/GZ;TCYD/__%Q,``/`Z`(#2<T(5D</_
M_Q?W8PCY^&<(^?EK"/GZ;PCY+OS_EQ\@`]4_(P/5_7N^J>$%@%+]`P"1\PL`
M^?,#`*K6^_^7'P``\6`&@)KS"T#Y_7O"J+\C`]5`_/\7/R,#U?U[O:D-`H+2
M_0,`D?]C+<O_`P+YX0``L"'41_DB`$#YX@<(^0(`@-)@!@"T]1L(^?4#`*H!
M`$`YP04`-/,3"/GT%PCY7?S_EP($`)'S`P"J7P1`\0@'`%3T(P"1X0,5JN`#
M%*JE^_^78`8`T8`"`(L?`!3KJ```5`<``!0?]!\X'P`4ZX```%0!`$`Y/[P`
M<6#__U3@`Q2JX06`4J?[_Y?@!`"T'P`4ZR@$`%3@`Q2J$OS_E^$``+`AU$?Y
MXP=(^2(`0/EC``+K`@"`TB$%`%3S$TCY#0*"TO072/GU&TCY_V,MB_U[PZB_
M(P/5P`-?UO4;2/G@``"P`-1'^>('2/D!`$#Y0@`!ZP$`@-)!`P!4````\`!`
M%9$-`H+2_V,MB_U[PZB_(P/5]/O_%Q\``#G?__\7``"`TM___Q?@``"P`-1'
M^>('2/D!`$#Y0@`!ZP$`@-+A``!4\Q-(^0```/#T%TCY`$`5D?4;2/GK__\7
MPOO_E_,3"/GT%PCY]1L(^;[[_Y<?(`/5/R,#U?^#`='@``"P`-1'^?U[`:G]
M0P"1\U,"J10``/#S$P"1]5L#J91"%I'W8P2I^2L`^?4``+"U^D?Y`0!`^>$'
M`/D!`(#2X0,3JN`#%*KD_/^7X`$`M*("0/GC!X"Y0`P#BP$$0/E!>"/XX?[_
MM`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JM;\_Y=@_O^U]0``L+7Z1_D4``#P
ME((6D>$#$ZK@`Q2JSOS_E^`!`+2B`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0!
M"$#Y`00`^0`@`)&A__^UX0,3JN`#%*K`_/^78/[_M?4``+"U^D?Y%```\)2B
M%I'A`Q.JX`,4JKC\_Y?@`0"TH@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T`0A`
M^0$$`/D`(`"1H?__M>$#$ZK@`Q2JJOS_EV#^_[7U``"PM?I'^10``/"4XA:1
MX0,3JN`#%*JB_/^7X`$`M*("0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!
M!`#Y`"``D:'__[7A`Q.JX`,4JI3\_Y=@_O^U]@``D-;Z1_D4``#0E0(7D>$#
M$ZK@`Q6JC/S_E^`!`+3"`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`
M^0`@`)&A__^UX0,3JN`#%:I^_/^78/[_M?8``)#6^D?Y%0``T+5"%Y'A`Q.J
MX`,5JG;\_Y?@`0"TP@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`
M(`"1H?__M>$#$ZK@`Q6J:/S_EV#^_[7W``"0]_I'^14``-"V8A61X0,3JN`#
M%JI@_/^7X`$`M.("0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``
MD:'__[7A`Q.JX`,6JE+\_Y=@_O^U^```D!C[1_D6``#0UX(7D>$#$ZK@`Q>J
M2OS_E^`!`+0"`T#YXP>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A
M__^UX0,3JN`#%ZH\_/^78/[_M?D``)`Y^T?Y%P``T/C"%Y'A`Q.JX`,8JC3\
M_Y?@`0"T(@-`^>,'@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__
MM>$#$ZK@`QBJ)OS_EV#^_[7Y``"0.?M'^1@``-`8`QB1X0,3JN`#&*H>_/^7
MX`$`M"(#0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A
M`Q.JX`,8JA#\_Y=@_O^U^0``D#G[1_D8``#0&*,5D>$#$ZK@`QBJ"/S_E^`!
M`+0B`T#YXP>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3
MJN`#&*KZ^_^78/[_M>$#$ZH```#0`$`8D?7[_Y?A`P"J8```M.#"%Y&Y_/^7
MX0,3J@```-``H!B1[?O_E^$#`*J```"T````T```&9&P_/^7X0,3J@```-``
M0!F1Y/O_E^$#`*J@`@"TH&(5D:C\_Y?@``"0`-1'^>('0/D!`$#Y0@`!ZP$`
M@-*A`@!4_7M!J8`"%Y'S4T*I`0``T/5;0ZDAX!F1]V-$J?DK0/G_@P&1OR,#
MU9;\_Q?A`Q.J````T`"`&9'*^_^7X0,`JB#]_[3`@A>1COS_E^;__Q>(^O^7
M/R,#U?^#`-'B``"00M1'^0```-#]>P&I_4,`D>$3`)%#`$#YXP<`^0,`@-(`
M@!>1M_O_EP`"`+0``$`Y'\``<0080'K@!Y\:X0``D"'41_GC!T#Y(@!`^6,`
M`NL"`(#2X0``5/U[0:G_@P"1OR,#U<`#7]8``(!2]/__%VCZ_Y<_(P/5_P,%
MT>D``)`IU4?Y[0,$D?U[!ZG]PP&1[`:`$NH``)!*Y4?YX".`/>L/@!+A)X`]
MZ`,`D>(K@#WC+X`]Y#.`/>4W@#WF.X`]YS^`/>&+$*GB`P"J(0"`4N.3$:GC
M`PBJY9L2J>>?`/E``4#Y)`%`^>0W`/D$`(#2Y`,%D>23`JGDHP"1[1\`^>PO
M""F`!$"MY",!D8`$`*T`!0"M0_K_E^`?@%+I^?^7/R,#U?U[O*G]`P"1\U,!
MJ?5;`JGW&P#Y_T-`T?\#`OG_0P#1_P,"^>$``)`AU$?YXT-`D?0#`"I"`(!2
M)`!`^60$`/D$`(#2`0"`TJGY_Y<3!`#1X`,3ZV$^0)(`/$"2($2`VG,"`.ND
M!@!4%0&`TO8#`)$U`*#R]P``L!\@`]7A`Q.JX`,4*@(`@%*9^?^7'P0`L>`%
M`%3B`Q6JX0,6JN`#%"H'^O^7'P0`,<`$`%0`?$"3'QP`\<D#`%0`(`#1P`(`
MJZ,``%0:```4``0`T1\`%NOC`@!4`@!`^>$*0/E?``'K0?__5```%LL``!.+
MX0``D"'41_GC0T"19`1`^2(`0/F$``+K`@"`TH$"`%3_0P"1_T-`D?-30:GU
M6T*I]QM`^?U[Q*B_(P/5P`-?UG-"0-%_0D"Q0?K_5```@)+L__\7````T`!`
M&I&"__^7````T```&I%___^7Y?G_ES\C`]7]>[^I_0,`D<GY_Y=T^?^70```
MM```0/G]>\&HOR,#U<`#7]8?(`/5'R`#U3\C`]7_`P'1X0``D"'41_G]>P&I
M_4,`D?-3`JGT`P"J]5L#J14``-"V@AJ1(@!`^>('`/D"`(#2X`,6JN$3`)$$
M^_^7@```M`$`0#GS`P"J`0(`->```)``U$?YX@=`^0$`0/E"``'K`0"`TJ$&
M`%3A`Q2JH((:D?U[0:GS4T*I]5M#J?\#`9&_(P/5N?O_%^$#%*IO^?^7P`$`
MM.```)``U$?YX@=`^0$`0/E"``'K`0"`TF$$`%3]>T&I\U-"J?5;0ZG_`P&1
MOR,#U<`#7];@`Q2J\_G_E_4#`*K@`Q.J\/G_EZ`"`(L`"`"1J?G_E^8#$ZH"
M`("2(0"`4N0#%*KS`P"J!0``T`,``-"EX!618R`6D>?Y_Y?@``"0`-1'^>('
M0/D!`$#Y0@`!ZP$`@-*!``!4X0,3JN`#%JK/__\7B/G_ES\C`]7_@P;1X0``
ML"%``)$DH`"1XD,!D?U[%*G]`P61XP``D&/41_GS4Q6I\^,`D2@D0:GU6Q:I
M]0,`JB:<1:GW8Q>I^(,`D8$(0*U@`$#YX)\`^0``@-*`",`]]',`D2000/D6
M``#0(S1`^<!B%9'A`Q2J00@`K6,*`/D$"P#YZ"<"J4`(@#WFGP.IH/K_EX``
M`+0!`$`Y]P,`JL$4`#7Y:QBI1OG_E_'X_Y<`#P"T&0!`^=D.`+3@`QFJJ/G_
MEP#X?],`!`"18?G_E_,#`*HD`T`Y]P,`JF0!`#0:``#06N,:D>`#$ZKC`QJJ
M`@"`DB$`@%*>^?^7<PH`D20?0#@D__\U````T/EC`9$``!F1`P``%""'0/B@
M`0"TX0,4JGOZ_Y?S`P"J8/__M`$`0#DA__\TMOK_E^#^_S3@`Q.J5_G_E_,#
M`*I@`0"U$P-`^3,!`+1@`D`Y@`L`-.`#$ZJK^O^78`H`-1,'0/D8(P"1,___
MM>`#$ZIY^?^7^`,`JN`#%ZIV^?^7&0,`"SD3$!$:``#0.7]`D^`#&:HL^?^7
MYP,7JN0#$ZI%`Q:1!@``T`,``-#&`!N18R`;D0(`@)+X`P"J(0"`4FGY_Y?@
M`QBJ`3B`4D+Y_Y<?!``QH0``5/OX_Y<%`$"YOT0`<0$)`%3A`P*1X`,8JAWY
M_Y?S`P`JH```->"30+D`#!02'Q!`<8`&`%3@``"0`.1'^0(``-"C`D#YY`,8
MJ@``0/E"8!R1(0"`4O+X_Y<7`(#2X```D`#41_GBGT#Y`0!`^4(``>L!`(#2
M81X`5/U[5*G@`Q>J\U-5J?5;5JGW8U>I^6M8J?^#!I&_(P/5P`-?U@CY_Y?Y
M`P"J8`(`M7,B`)%@`D#Y(`<`M.$#%*H=^O^78/__M`$`0#G!_O\U<R(`D?C_
M_Q?@`Q.J&",`D?GX_Y?S`P"J8/3_M*S__Q<3`(#2JO__%R/Y_Y<`^'_3``0`
MD7O__Q?WFT"YMOC_E_\"`&M!^?]4X)-`N?O+`/D`(``2'P`'<:`$`%3[RT#Y
MP___%^```)``Y$?YY`,8JJ,"0/D"``#0``!`^4)@&Y$A`(!2M/C_E\+__Q?B
M_O^7X```D`#41_GBGT#Y`0!`^4(``>L!`(#2P18`5/U[5*G@`Q>J\U-5J?5;
M5JGW8U>I_X,&D;\C`]7+^/\7H`&`TK7X_Y<9``#0\P,`JCG#&I'W`P"J9`J`
M4E/__Q?@`QFJK?C_E^$#%*KW`P"J````T`#`'9'8^?^7X0,`JB`+`+2@`D#Y
MU/O_E_L#`*J@"@"TX`,;JN3X_Y?Y`P"J'PP`<>T!`%0`?$"3`0``T``0`-$A
MX!V18`,`BZ/X_Y<``0`U/Q,`<0`/`%0Y%P!18,MY.!^\`'&`#@!4'R`#U>$#
M%*H4``#0@((7D;OY_Y>@``"T``!`.1_``'$$&$!ZP0``5.`#&ZH!`(!2P_C_
ME_4#`"K`!@`U@((7D0$``-`AX!F1=?K_EUH#%I$5``#0M<(AD1D``-#\]_^7
M.>,>D>8#`"KE`QJJYP,5JN0#&*K@`Q>J`P``T`(`@))CH!Z1(0"`4K7X_Y<1
M```42_C_EP``0+D?1`!Q00(`5.OW_Y?U`P#Y<P8`$>8#`"KG`Q,JY0,:JN0#
M&*KC`QFJX`,7J@(`@)(A`(!2I/C_E^`#%ZH!.(!2??C_EQ\$`#&`_?]4X`,8
MJH'X_Y?A`Q>JP&(5D4KZ_Y?@`Q>J;/[_E_O+0/E*__\7NP)`^:O__Q<#_O^7
M^0,`JB#Y_[<!*`#1`@"`4N`#%2K[`P21N/?_E^`#%2KA`QNJP@"`TBCX_Y<?
M&`#Q`08`5.$#0;D`8(A2(&BH<C\``&LA]_]480M`>0"IB%(_``!KH?;_5"'+
M`-$"`(!2X`,5*O,C!)&D]_^7X`,5*N$#$ZH"!8#2%/C_EQ^@`/&!`P!4Y@,3
MJD4#%I'D`QBJX`,7J@<``-`#``#0Y\`AD6-@'I$"`("2(0"`4O_#!#EF^/^7
MQ___%[4&0/FU\?^TX`,5JEWX_Y<?#`#Q*?'_5``0`-$!``#0H`(`BR$`'I$>
M^/^7'P``<7L3E9J!__\7````T``@'I&9_?^7^\L`^?[W_Y?Y:QBI^\L`^?OW
M_Y<?(`/5'R`#U3\C`]7_0P'1X@``D$+41_D```#0_7L!J?U#`)$``!>1\U,"
MJ530.]7S``"0<^I'^?5;`ZGV$P"1X0,6JO<C`/F5:G/X0P!`^>,'`/D#`(#2
MHL)".:+&`CD>^?^7@```M`$`0#D_Q`!Q0`L`5"'\_Y>5:G/XX`,5J@$``-!C
M`(!2(4`?D2(`@%)R]_^7]0,`JF`!`+2A"D#Y`@``T(!J<_A"8!^1(0!`^7+W
M_Y>@"D#Y`0!`^2`,0+D`"K`W@&IS^`$``-!C`(!2(8`?D2(`@%+W``"P7_?_
ME_4#`*I@`0"TX0,6J@```-``H!61^?C_E^(#`*I`!P"TH0I`^8!J<_@A`$#Y
M6_?_EY5J<_@B`(!2`0``T"&@'Y'@`Q6J*??_EP(``-#A`P"J0@`@D>`#%:I0
M]_^7@FIS^/1"`I'A`Q:J````T`!@%9%?Q`(YX?C_EX`*`/GS`P"JP`(`M`$X
M@%+@`Q.JS_?_EP$$`!$_!`!Q!(A1>J$$`%3@``"0`-1'^>('0/D!`$#Y0@`!
MZP$`@-*A`P!4_7M!J?-30JGU6T.I]R-`^?]#`9&_(P/5P`-?UH`&0/D$_O^7
M@`H`^?,#`*K@_/^U````T``@()&I]_^7``1`.0#U_S2E__\7X$("D:(*0/D!
M!$#Y0`!`^2$`0/D-^O^7Q?__%X!J<_B)]_^7K___%W?W_Y?W0@*1XP,`*N(#
M$ZH```#0`,`@D>$&0/DA`$#YD_?_EQ\@`]4?(`/5/R,#U?_#`-'A``"0(=1'
M^?U[`:G]0P"1\U,"J?,#`*H```#0(@!`^>('`/D"`(#2`(`7D>$3`)&:^/^7
M(`$`M```0#D?P`!Q!!A`>N`'GQI_`@#QX0>?&C\``&JA`0!4P```\`#41_GB
M!T#Y`0!`^4(``>L!`(#2000`5/U[0:GS4T*I_\,`D;\C`]7``U_68`)`.6#^
M_S3@`Q.J)OO_E^$%@%+T`P"J\O;_EQ\``/&`!H":7_?_EP$``+""`(#2(0`;
MD0/W_Y?`_/\UP```\`#41_GB!T#Y`0!`^4(``>L!`(#2X0``5/U[0:G@`Q.J
M\U-"J?_#`)&_(P/5TOC_%RSW_Y<?(`/5'R`#U1\@`]4_(P/5_7N_J0'@`)'#
M``#P8]1'^?T#`)'_0PK1!.`!D5'D`&_B`P"1\.4`;X?D`&]E`$#YY4<!^04`
M@-+C`P*J(P!`;2($P3QC.(`.001@;T`$6&]C""`N0@1(;R946$\`'#%.9*0@
M+R%42$_#'#!.`!RB3B$<)TX`'*-.!1RA3F2,GTR?``'KP?W_5/"?0*U"H`F1
MYH]!K>&C`9'EDT*MX1_`/?'E`&\B@-D\(4``D2``WSP`'")N`!PC;@`<,&[P
M'*=.QQRF3F8<HTX"5$%/``1A;Z,<I4Z%'*1.)!RA3D`<H$X!'#%.(8"`/#\`
M`NO!_?]4!RA`J20SC](()$&I1%"K\N4_0*DC=)W2XOQ;T^S\0M-"%`>JC'D'
MJB$!",HCVZWR(0`*BB$`"<JE``2+(D`BBT']0M,+$$#Y(7@*JBU\0))"``6+
MI0$(RD(`"POF0T&II0`'BJ4`",KO`02+3OQ;TZ4`"8O.%0*J(0`,RJ4`#XLA
M``**I0`."T_\0M,A``W*XGD"JL8`!(NN_%O3(0`(B\X5!:HA``:+A@$"RB$`
M#@N,?4"2Q@`%BJ[\0M/&``S*$`($B\8`#8LO_%O3S7D%JN\5`:KN$T#Y10`-
MRL8`$(M"?$"2Q@`/"Z4``8JE``+*,/Q"T\X!!(NE``R+S_Q;TPQZ`:KO%0:J
MI0`.BZ4`#PNA`0S*S_Q"TR$`!HKF>0:JK7U`DNZ_0JDA``W*(0`"B[#\0M/"
M`02+KOQ;TR$``HN"`0;*0@`%BHQ]0)+.%06J0@`,RBX`#@L%>@6JX0$$BT(`
M#8M"``&+P0`%RM!\0)(A``Z*(0`0RLW]6],A``R+K14.JN^S0ZE-``T+QOU"
MT\YX#JJF?$"2X@$$BZ_]6],A``*+H@`.RN\5#:I"``V*+P`/"Z7]0M-"``;*
M@0$$BZ5X#:I"`!"+0@`!B^S]6]/!`07*\/U"TXP5#ZHA``^*#WH/JDP`#`OM
MPT2ISGU`DB$`#LHA``:+AOU;T\84#*JB`02+$`($BR$``HNB``_*+0`&"Z5\
M0))"``R*AOU"TT(`!<K&>`RJH?U;TT(`#HM"`!"++!0-JK#]0M/A`0;*(0`-
MB@UZ#:KNPT6I3``,"^]]0)(A``_*(0`%BX7]6].E%`RJP@$$BQ`"!(LA``*+
MP@`-RBX`!0O&?$"20@`,BH7]0M-"``;*I7@,JL']6]-"``^+0@`0BRP4#JK0
M_4+3H0$%RB$`#HH.>@ZJ[\-&J4P`#`NM?4"2(0`-RB$`!HN&_5O3QA0,JN(!
M!(L0`@2+(0`"BZ(`#LHO``8+I7Q`DD(`#(J&_4+30@`%RL9X#*KA_5O30@`-
MBT(`$(LL%`^J\/U"T\$!!LHA``^*#WH/JNW#1ZE,``P+SGU`DB$`#LHA``6+
MA?U;TZ44#*JB`02+$`($BR$``HO"``_*+0`%"X7]0M.E>`RJ0@`,BJ']6]/&
M?$"2+!0-JN$!!<HA``V*[WU`DD(`!LHA``_*0@`.BR$`!HONFTBI0@`0BTP`
M#`NP_4+3#7H-JI#]0M/"`02+COU;TR$``HO.%0RJH@`-RBX`#@NE?$"20@`,
MBD(`!<H,>@RJP0`$BT(`#XO&_5O30@`!B^]/0/FA`0S*QA0.JJU]0)+2``(+
M(0`.BB$`#<KD`02+(0`%B]#]0M-%_EO3#GH.JN]30/DA``2+I102JD9`)HNP
M``$+A`$.RH0`!DKB`0.+A``-BP;^6]--_D+3A``"B^)70/FR>1*JQA00JB5`
M)8O/``0+P0$2RB4`!4I!``.+HD`LBPS^0M/E_5O3C7D0JD(``8NE%`^JX5M`
M^;$``@N&0":+1`(-RH0`!DKL_4+3)@`#BX%`+HLD_EO3CWD/JB$`!HN$%!&J
MYE]`^9```0M%0"6+H@$/RD4`!4HN_D+3T7D1JJQ`,HO"``.+!?Y;T^9C0/F"
M`0*+I100JB1`)(OA`1'*K@`""R0`!$H,_D+3P0`#BX9`+8N0>1"JP0`!B^9G
M0/G$_5O314`EBX04#JHB`A#*C0`!"T(`!4K&``.+0D`OB\S]0M..>0ZJ0@`&
MB^9K0/FE_5O3I10-JB1`)(L!`@[*KP`""R$`!$JL_4+3C7D-JL8``XLA0#&+
MY/U;TR$`!HM%0"6+YF]`^<(!#<J$%`^J10`%2I$``0NL0#"+\/U"T\(``XOF
M<T#Y#WH/JB7^6],D0"2+H0$/RH(!`HNE%!&J)``$2K```@O!``.++/Y"TX9`
M+HN,>1&JP0`!B^9W0/E%0"6+!/Y;T^(!#,J$%!"J0@`%2HX``0O&``.+0D`M
MBPW^0M/Q>T#Y0@`&BZ9Y$*HD0"2+Q?U;TX$!!LJE%`ZJ(0`$2JT``@LP`@.+
M(4`OB\_]0M,A`!"+[GD.JO!_0/FD_5O3A!0-JD5`)8NQ_4+3P@`.RH\``0LM
M>@VJ10`%2@("`XOP@T#Y)$`DB\$!#<JL0"R+)``$2N7]6].E%`^JAD`FB_']
M0M,!`@.+P0`!BX(!`HLF>@^JK``""T5`)8NB`0;*0@`%2H3]6]-"0"Z+A!0,
MJO"[4*F1_4+3CP`!"RQZ#*HD0"2+P0`,RN7]6],A``1*\?U"TZ44#ZH0`@.+
M+WH/JD(`$(LA0"V+[<=1J;```@O.`0.+14`EBP3^6],A``Z+A!00JH(!#\J.
M``$+0@`%2D)`)HNE`0.+#?Y"TT4`!8O&_5O3HGD0JL84#JHD0"2+X0$"RLT`
M!0LD``1*(0(#BX1`+(O1_4+3\)=`^80``8NL_5O3(7H.JHP5#:JF0":+10`!
MRHX!!`NE``9*$`(#BZ5`+XNO_4+3[WD-JJ4`$(OPFT#YQOU;T\84#JJ,0"R+
M)``/RLT`!0N,``Q*T?U"TP0"`XN"02*+L/U;TT(`!(LD>@ZJID`FB^R?0/D0
M%@VJY0$$RD(`$`NE``9*KOU"TZ%`(8O%>0VJA@$#BT[\0M.,``6J0_Q;TV,4
M`JJ,`0**PGD"JB$`!HOM.U2I(0`#"Z,`!`J&FY?2C`$#JF;CL?*#02^++_Q"
MTZP!!HLM_%O3K14!JF,`#(NL``*J8P`-"XP!`8I-``4*C`$-JN%Y`:K.`0:+
MA$$DBVW\6]-,``&JK14#JH0`#HN$``T+C`$#BBT``@IN_$+3C`$-JHW\6].%
M026+S'D#JN\[5:FC%02J+0`,JN\!!HO.`0:+I0`/BX_\0M.C``,+I0$$BHT!
M`0JE``VJ;?Q;TZ5`(HOB>02JK14#JH0!`JJE``Z+A``#BJ4`#0M-``P*A``-
MJFW\0M.$0"&+H7D#JN\W5JFN_%O3SA4%JD,``:IC``6*[P$&BZT!!HN$``^+
MK_Q"TX0`#@LN``(*8P`.JN5Y!:IC0"R+COQ;T\X5!*HL``6J8P`-BXP!!(KM
MNT#Y8P`."ZX``0J/_$+3C`$.JN1Y!*J"02*+;OQ;TZP!!HO.%0.J[;]`^4(`
M#(NL``2J0@`."XP!`XJ.``4*C`$.JF_\0M/C>0.JK0$&BX%!(8M._%O3SA4"
MJHP``ZHA``V+C`$"BB$`#@MN``0*C`$.JD[\0M/">0*JA4$EB^T[6*DO_$+3
MK`$&BRW\6].M%0&JI0`,BVP``JJE``T+C`$!BDT``PJ,`0VJX7D!JLX!!HN$
M022+K?Q;TTP``:JM%06JA``.BX0`#0N,`06*+0`""J[\0M.,`0VJC?Q;TX-!
M(XO,>06J[SM9J:T5!*HE``RJI0`$BN\!!HO.`0:+8P`/BX_\0M-C``T+C0$!
M"J4`#:KD>02JHD`BBVW\6].M%0.JA0$$JD(`#HNE``.*0@`-"XT`#`JE``VJ
M;?Q"TZ%`(8NE>0.J[S=:J4[\6]/.%0*J@P`%JF,``HKO`0:+K0$&BR$`#XNO
M``0*(0`."V,`#ZI._$+3;$`LB\)Y`JHC_%O3C`$-BV,4`:JM``*J+_Q"TX,!
M`PNL`0&*X7D!JDT`!0KN/UNIC`$-JH1!)(MM_%O3K14#JLP!!HLN``(*A``,
MBTP``:J$``T+C`$#BHP!#JIM_$+3K7D#JN\!!HN%026+COQ;T^SC0/FC``^+
MSA4$JB4`#:IC``X+I0`$BJX!`0J/_$+3I0`.JF[\6].B0"*+A0$&B^1Y!*K.
M%0.J0@`%BZ4!!*I"``X+;OQ"TZ4``XK#>0.J[+M<J8\`#0JE``^J3_Q"TZ5`
M(8M!_%O3(10"JHP!!HNE``R+C``#JJ4``0N,`0**80`$"N)Y`JJ,`0&J4``#
M"H%!+8O-`0:+K/Q;TR$`#8OO[T#Y;0`"JHP5!:JM`06*C@$!"ZT!$*JD022+
ML/Q"T^T!!HO&_5O3[_-`^80`#8O&%`ZJ#7H%JM$`!`LL0"R+00`-RL4ZF-(A
M``Q*14RY\B%`(XOL`06+T/U"TR/^6]/O]T#Y#GH.JF,4$:HA``R+;``!"X9`
M)HND`0[*(T`CBX0`!DKF`06+@D`BBR_^0M.$_5O3\7D1JD(`!HN$%`RJYOM`
M^9(``@O!`1'*1$`DBR,``TK!``6+9D`MBXW]0M-#_EO3L'D,JL8``8MC%!*J
MX?]`^6\`!@LB`A#*3/Y"TT(`!$HD``6+0D`NB^']6].->1*J1``$B^(#0?DA
M%`^J+@`$"\-`(XL&`@W*[/U"T\,``TI&``6+8T`QB\+]6]./>0^J8P`&B^8'
M0?E"%`ZJ40`#"X%`(8ND`0_*8D`BBX$``4K$``6++$`PB]#]0M,A_EO3#GH.
MJN8+0?F$`02+(101JN,!#LHP``0+8@`"2BS^0M/#``6+1D`MBP+^6].,>1&J
MPP`#B^8/0?E"%!"J30`#"X%`(8O$`0S*$?Y"TX$``4K&``6+)$`OBZ']6]/O
M$T'YA``&BR$4#:HF>A"J8D`BBS``!`N#`0;*[P$%BV(``DJQ_4+30T`NBP+^
M6]/N%T'Y+7H-JF,`#XM"%!"J3P`#"X%`(8O$``W*8D`BBX$``4K$`06++$`L
MBP[^0M/A_5O3T'D0JH0!!(LA%`^J[!M!^3$`!`NC`1#*@4`ABV(``DJ#`06+
M1D`FB^S]0M,B_EO3CWD/JL,``XM"%!&JYA]!^4X``PL$`@_*8D`BBX$``4K&
M``6+)$`MBRW^0M/!_5O3A``&B^PC0?FF>1&J(10.JN,!!LHM``0+8@`"2HP!
M!8M#0#"+T/U"TZ+]6],.>@ZJ8P`,B^PG0?E"%`VJ40`#"X%`(8O$``[*8D`B
MBX$``4J$`06++$`OBZ_]0M,A_EO3[7D-JH0!!(LA%!&J["M!^3``!`O#`0W*
M+_Y"TV(``DJ,`06+0D`FBP/^6]-&``R+8Q00JN(O0?GL>1&J@4`ABV\`!@ND
M`0S*PT`CBX0``4I!``6+A$`NB^+]6],._D+3A``!B_$S0?G!>1"J0A0/JH8!
M`<I.``0+PP`#2C`"!8MF0"V+\?U"T\/]6]/M-T'Y8Q0.JB]Z#ZK&`!"+<``&
M"X)`(HLD``_*QD`CBX0``DJB`06+C$`LB\W]0M,$_EO3C`$"B^([0?F$%!"J
MKGD.JH,`#`OM`0[*YT`OBZT!!DI&``6+H4$ABV+\6]-"%`.J(0`&B^T_0?DA
M``(+`OY"TX9!)(M">!"J)/Q;T\P!`LJ$%`&JC`$&2J8!!8ME_$+3Q@`'BZ-X
M`ZJ$``R+QP``T.?41_DA``H+0@`)"\4!"PN$``8+8P`("P0$`*D#"`&I!1``
M^>)'0?GA`$#Y0@`!ZP$`@-*A``!4_T,*D?U[P:B_(P/5P`-?UOKR_Y<?(`/5
M/R,#U?U[OZD`$(#2_0,`D0#S_Y<?&`#Y(@``D"$``)`?>`"Y09C!/2(``)`B
ME,$]0)S!/0($`*T`"(`]_7O!J+\C`]7``U_6'R`#U1\@`]4_(P/5_7N\J4)\
M0)/]`P"1\U,!J13@`)'S`P&J]5L"J?4#`*KV`P*J]V,#J06,0JD`>$"YI`P"
M"[\`!.MCE(.:8G1"BZ2*`JF@`P`UW_X`<:T%`%36`@%1V'X&4Q<'`!'W:GK3
M=P(7BV`&0*W@`Q6J@`8`K6`&0:US`@&1@`8!K9S[_Y=_`A?K`?__5-8:&$OA
M`Q>JX`,4JL)^0)-=\O^7MGH`N?-30:GU6T*I]V-#J?U[Q*B_(P/5P`-?UA<(
M@%+W`@!+_P(6:X#"((OWTI8:^'Y`D^(#&*I.\O^7H'I`N>`"``N@>@"Y'P`!
M<<']_U36`A=+<P(8B^`#%:I]^_^7T___%_<#$ZKB__\7'R`#U3\C`]7]>[RI
MX@^`$OT#`)'S4P&I]`,`JO,#`:KU6P*I-N``D>@;`/TU%$#Y*!A`_:`B`U,!
M!``1PLH@."!\0),_X`!QC0L`5`((@%)"``%+`0"`4L`"`(M"?$"3X?+_E^`#
M$ZI?^_^7WQH`^0`$`$_``@"MP`J`/04%<'\`!6A_!`5X?Z$"9Y[@`Q.J(P1H
M?R($<'^@!`-N(01X?X`$!6X`!0=N8`0);D`$"VX@!`UNH!X/3F`Z`/U*^_^7
M80)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3@0H`.6$"0/F!
M#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!&@`Y809`^8$>
M`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J`#EA"D#Y@2X`
M.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`.6$.0/F!/@`Y
M81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y81)`^8%.`#GS
M4T&I]5M"J>@;0/W]>\2HOR,#U6SR_Q<"!X!20@`!2\`"`(L!`(!20GQ`DX;R
M_Y>K__\7PP``\&,$0/D:\O\7'R`#U?U[OZG]`P"1_7O!J,`#7]8!``(`````
M`"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O
M<')O8R\E:2\E<P``````+@````````!005)?5$5-4```````````4$%27U!2
M3T=.04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"````
M``````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$
M14)51P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``
M````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@``````
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```````````Q````
M`````&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?3$E"4D%2
M65]0051(`%-94U1%30``)3`R>`````!P87(M`````"5S)7,E<R5S````````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R;``````N<&%R`````'-H
M;W)T(')E860````````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,``````````!@`````````<&5R;``````P````
M`````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8Q````56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``````````"UE````````+2T```````!54T52`````%5315).04U%
M``````````!435!$25(``%1%35!$25(`5$5-4`````!435```````"]T;7``
M````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L
M("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y0
M05(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB
M*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP
M,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?
M.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@
M)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L
M92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H
M+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!
M4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]
M("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y
M<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E
M=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2![
M"F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@
M(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*
M;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I
M;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T
M('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR
M96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE
M(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C
M86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A
M8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&
M24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M
M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E
M='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92([
M"FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D[
M"B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE
M?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I
M;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@
M>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B
M(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'
M24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD
M9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF
M("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L
M("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO
M8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B
M)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F
M;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN
M84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C
M(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE
M*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE
M;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\
M7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ
M*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M0
M86-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@
M=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L
M;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E
M;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q
M6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET[
M"GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!
M3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M
M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM
M>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U
M="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN
M9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA
M;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D
M:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H
M*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D
M9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*
M)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II
M9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.
M5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M)&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F
M("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,
M3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!
M0TA%```!(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````
M```````````!&P,[#`$``"````"`B/__W`8``,"*__\D`0``$(O__S@!``!`
MB___3`$``("+__]@`0``T(O__X0!``#@B___F`$``.",__\(`@``A(W__S0"
M````C___C`(``#21___D`@``0)+__QP#``"PDO__1`,``."2__]8`P``T)/_
M_XP#``#@D___H`,``$"6__\,!```=);__S0$````F/__J`0``-2<___H!```
M5)W__Q`%````GO__+`4``&"?__]T!0``D)___Y@%``#4H/__W`4``!"G__]L
M!@``0*G__Z0&``!0JO__$`<``!"[__]`!P``8+O__V0'``!PO/__H`<``$"^
M___@!P```````!```````````7I2``1X'@$;#!\`$````!@```"4B?__-```
M``!!!QX0````+````-")__\P`````````!````!`````[(G__SP`````````
M(````%0````8BO__2`````!!#B"=!)X#0I,"3M[=TPX`````$````'@```!$
MBO__!`````````!L````C````$"*___\`````$$M00Y`G0B>!T*3!I0%0I@!
MEP)&E@.5!%76U4'8UT/>W=/4#@!!+4$.0),&E`65!)8#EP*8`9T(G@<M3];5
M0=C70=[=T]0.`$$M00Y`DP:4!9T(G@<M0I<"F`%!V-<`*````/P```#0BO__
MI`````!!+4$.L`%$G02>`T*3`E8*W=[3#@!!+4$+``!4````*`$``$B+__]X
M`0```$$M00[``4.=!IX%1I0#DP1$U--)W=X.`$$M00[``9,$E`.=!IX%+4&6
M`94"=0K4TT'6U4$+2=/4U=9!E`.3!$&6`94"````5````(`!``!LC/__-`(`
M``!!+4$.8$&="IX)0I,(E`=-E0:6!9<$F`,"0`K=WM?8U=;3U`X`02U!"TJ:
M`9D"70K:V4$+2-G:0ID"F@%#V=I!F@&9`D+:V30```#8`0``2([__PP!````
M02U!#C"=!IX%10[`(),$E`.5`I8!90H.,$/>W=76T]0.`$$M00L`)````!`"
M```<C___<`````!!+4$.()T$G@-#DP*4`4_>W=/4#@!!+1`````X`@``9(__
M_S``````````,````$P"``"`C___[`````!!+4$.,)T&G@5%#M!`DP24`Y4"
M;0H.,$3>W=73U`X`02U!"Q````"``@``/)#__P@`````````:````)0"```X
MD/__7`(```!!+4$.4)T*G@E%#N`ADPB4!Y4&E@5?"@Y00][=U=;3U`X`02U!
M"TB7!$*8`T.9`D.:`74*UT'80=E!VD$+5@K70=A!V4':00M$U]C9VD&7!$&8
M`T&9`D&:`0``)``````#```LDO__-`````!!+4$.()T$G@-#DP)&WMW3#@!!
M+0```'`````H`P``.)+__X@!````02U!#C"=!IX%0P[`($B5`D23!$&4`V33
M0M1!U4$.,$'>W0X`02U!#L`@E0*=!IX%+4'52PXP0=[=#@!!+4$.P""3!)0#
ME0*=!IX%+4P*TT+40M5!"T'3U-5!DP1!E`-!E0(`/````)P#``!0D___U`0`
M``!!+4$.8$.="IX)0I,(E`=&E0:6!9<$F`.9`@,<`0K=WMG7V-76T]0.`$$M
M00L``"0```#<`P``Y)?__X``````02U!#B!$G0*>`54*W=X.`$$M00L````8
M````!`0``#R8__^L`````$$M00[``D2=&IX91````"`$``#,F/__8`$```!!
M+4$.0)T(G@=%#L"`!),&E`65!)8#EP)"#M"`!'P*#L"`!$$.0$3>W=?5UM/4
M#@!!+4$+````(````&@$``#DF?__*`````!!+4$.$)T"G@%&WMT.`$$M````
M0````(P$``#PF?__1`$```!!+4$.0$.=!IX%0I,$E`-"E0*6`5D*W=[5UM/4
M#@!!+4$+3@K=WM76T]0.`$$M00L```",````T`0``/":__\T!@```$$M00Z@
M`T6=#)X+1),*E`E#E0B6!T.7!I@%6)H#F00"<PK:V4'=WM?8U=;3U`X`02U!
M"U^;`D3;2]G:3MW>U]C5UM/4#@!!+4$.H`.3"I0)E0B6!Y<&F`69!)H#G0R>
M"RU(FP("8`K;00L"0MM!FP)!V=K;09H#F01!FP(````T````8`4``)R@__\H
M`@```$$M00Y01)T(G@=#DP:4!425!)8#0Y<"`EH*W=[7U=;3U`X`02U!"S0`
M``"8!0``E*+__P0!````02U!#C!#G02>`T*3`I0!6PK=WM/4#@!!+4$+6@K=
MWM/4#@!!+4$+,````-`%``"<@?__&`(```!!+4$.8$.=!IX%2),$E`.5`I8!
M`E<*W=[5UM/4#@!!+4$+`"P````$!@``.*/__[P0````02U!#A"=`IX!10Z@
M!0,D!`H.$$'>W0X`02U!"P```"`````T!@``R+/__T@`````02U!#A"=`IX!
M3M[=#@!!+0```#@```!8!@``]+/__PP!````02U!#D"=")X'0Y,&E`5#E026
M`T.7`I@!8@K>W=?8U=;3U`X`02U!"P```#P```"4!@``R+3__]`!````02U!
M#D"=")X'0Y,&E`5#E026`T(%2`("80K>W=76T]0&2`X`02U!"P`````````0
M````U`8``%BV__\,````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%`B`````````"(`
M```````!`````````/L"`````````0`````````+`P````````$`````````
M%0,````````,`````````/@:````````#0````````#,5````````!D`````
M````@/L!```````;``````````@`````````&@````````"(^P$``````!P`
M````````"`````````#U_O]O`````)@"````````!0`````````P#0``````
M``8`````````B`,````````*`````````)X$````````"P`````````8````
M`````!4````````````````````#`````````*#]`0```````@````````"(
M!0```````!0`````````!P`````````7`````````'`5````````!P``````
M````$P````````@`````````<`(````````)`````````!@`````````'@``
M```````(`````````/O__V\``````0``"`````#^__]O`````*`2````````
M____;P`````"`````````/#__V\`````SA$```````#Y__]O``````X`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````0&P```````!`;````````$!L````````0&P``
M`````!`;````````$!L````````0&P```````!`;````````$!L````````0
M&P```````!`;````````$!L````````0&P```````!`;````````$!L`````
M```0&P```````!`;````````$!L````````0&P```````!`;````````$!L`
M```````0&P```````!`;````````$!L````````0&P```````!`;````````
M$!L````````0&P```````!`;````````$!L````````0&P```````!`;````
M````$!L````````0&P```````!`;````````$!L````````0&P```````!`;
M````````$!L````````0&P```````!`;````````$!L````````0&P``````
M`!`;````````$!L````````0&P```````!`;````````$!L````````0&P``
M`````!`;````````$!L````````0&P```````!`;````````$!L````````0
M&P```````!`;````````$!L````````0&P```````!`;````````D/L!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````'P``````````````````"``"```````*4$%2+G!M"@``````
M````P%@```````!050``````````````````0%8```````"@6````````*A8
M````````L%@```````"X6```````````````````B%@```````"06```````
M````````````R%@```````!'0T,Z("A$96)I86X@,3,N,BXP+3DI(#$S+C(N
M,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E
M+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N
M=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`#@"````````.`(````````;`````````````````````0``````````````
M`````!,````'`````@````````!4`@```````%0"````````)```````````
M``````````0````````````````````F````!P````(`````````>`(`````
M``!X`@```````"`````````````````````$````````````````````-```
M`/;__V\"`````````)@"````````F`(```````#L``````````4`````````
M"````````````````````#X````+`````@````````"(`P```````(@#````
M````J`D````````&`````P````@`````````&`````````!&`````P````(`
M````````,`T````````P#0```````)X$```````````````````!````````
M````````````3@```/___V\"`````````,X1````````SA$```````#.````
M``````4``````````@`````````"`````````%L```#^__]O`@````````"@
M$@```````*`2````````8``````````&`````@````@`````````````````
M``!J````!`````(``````````!,`````````$P```````'`"````````!0``
M```````(`````````!@`````````=`````0```!"`````````'`5````````
M<!4```````"(!0````````4````5````"``````````8`````````'X````!
M````!@````````#X&@```````/@:````````&`````````````````````0`
M``````````````````!Y`````0````8`````````$!L````````0&P``````
M`-`#```````````````````0````````````````````A`````$````&````
M```````?`````````!\```````#,-0``````````````````0```````````
M`````````(H````!````!@````````#,5````````,Q4````````%```````
M``````````````0```````````````````"0`````0````(`````````X%0`
M``````#@5````````*!!```````````````````0````````````````````
MF`````$````"`````````("6````````@)8````````,`0``````````````
M````!````````````````````*8````!`````@````````"0EP```````)"7
M````````Z`8```````````````````@```````````````````"P````#@``
M``,`````````@/L!``````"`^P````````@````````````````````(````
M``````@`````````O`````\````#`````````(C[`0``````B/L````````(
M````````````````````"``````````(`````````,@````&`````P``````
M``"0^P$``````)#[````````$`(````````&``````````@`````````$```
M``````#1`````0````,`````````H/T!``````"@_0```````&`"````````
M```````````(``````````@`````````U@````$````#`````````````@``
M```````!``````"(````````````````````"````````````````````-P`
M```(`````P````````"(``(``````(@``0``````*```````````````````
M``@```````````````````#A`````0```#````````````````````"(``$`
M`````!X````````````````````!``````````$``````````0````,`````
M````````````````````I@`!``````#J`````````````````````0``````
*````````````````
